
History
=======

0.2.2 (2018-04-17)
------------------

* Minimise and shorten now only return encodings.
* Fixed shorten ordering bug.
* Fixed appveyor build process.

0.2.1 (2018-04-12)
------------------

* Generalised intersection code.
* Collated peripheral components code.
* Fixed documentation typos.
* More unittests.

0.2.0 (2018-04-11)
------------------

* New notion of short.
* Removed TrainTracks class, incorporated vertex cycles methods into MultiCurves.
* More performance.
* Simplified hypothesis strategy code.

0.1.2 (2018-02-19)
------------------

* Licence hotfix.

0.1.1 (2018-02-19)
------------------

* Fixed numpy dtype bug.
* Added first version of SLP data structure.
* Switched to MIT licence.
* Using tox-travis.
* Whitespace, formatting, Flake8.

0.1.0 (2017-12-11)
------------------

* First full release.

0.0.1 (2017-12-08)
------------------

* Test release on PyPI.
